#!/usr/bin/env python

"""Tests for `nym` package."""

import pytest

from click.testing import CliRunner

from nym import cli, fast, slow


def test_python_fib():
    res = slow.fib(33)
    assert res == 3524578


def test_nim_fib():
    res = fast.fib(33)
    assert res == 3524578


@pytest.mark.parametrize("n", [0, 1, 5, 20])
def test_implementations_match(n):
    assert slow.fib(n) == fast.fib(n)


def test_command_line_interface():
    """Test the CLI."""
    runner = CliRunner()
    result = runner.invoke(cli.main)
    assert result.exit_code == 0
    assert 'nim fib implementation is' in result.output
    help_result = runner.invoke(cli.main, ['--help'])
    assert help_result.exit_code == 0
    assert '--help  Show this message and exit.' in help_result.output



"""Cli script for nym."""
import sys
import click
import time

from nym import slow, fast

@click.command()
def main(args=None):
    """Console script for nym."""
    click.echo(f"Running fib(33)...")

    start = time.time()
    python_ret = slow.fib(33)
    python_time = time.time() - start

    restart = time.time()
    nim_ret = fast.fib(33)
    nim_time = time.time() - restart

    print("====================================")
    print(f"python ret: {python_ret}")
    print(f"python elapsed time : {python_time}")

    print(f"nim ret: {nim_ret}")
    print(f"nim elapsed time    : {nim_time}")

    print("====================================")
    times_faster = round(python_time / nim_time, 3)
    print(f"nim fib implementation is {times_faster}x faster than python's!")

    return 0


if __name__ == "__main__":
    sys.exit(main())  # pragma: no cover



#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

import nimporter


with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0', 'nimporter']

test_requirements = ['pytest>=3', ]

setup(
    author="Goncalo Magno",
    author_email='goncalo.magno@gmail.com',
    python_requires='>=3.10',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.10',
    ],
    description="Nim extension for Python, example project",
    entry_points={
        'console_scripts': [
            'nym=nym.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    # include_package_data=True,
    keywords='nym',
    name='nym',
    packages=find_packages(include=['nym', 'nym.*']),
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/gmagno/nym',
    version='0.1.1',
    zip_safe=False,
    ext_modules=nimporter.get_nim_extensions(
        platforms=[nimporter.WINDOWS, nimporter.LINUX, nimporter.MACOS]
    ),
    package_data={'': ['*.nim*']},  # Distribute *.nim & *.nim.cfg source files
    setup_requires = [
        "choosenim_install",        # Optional. Auto-installs Nim compiler
    ],
)
